# Sensitive Message Formatter

A message formatter for Guzzles log middleware. It replaces static sensitive data (e.g. credentials) in the whole log item.

From:
```
[2024-12-24 18:00:00] Logger.INFO: POST https://api.google.com/account/login HTTP/1.1 username=myUsername&password=mySecretPassword RESPONSE: 200 - {"sessid":"fv0Krhl...
```
To:
```
[2024-12-24 18:00:00] Logger.INFO: POST https://api.google.com/account/login HTTP/1.1 username=**********&password=**************** RESPONSE: 200 - {"sessid":"fv0Krhl...
```

## Installation

```
composer require d3/sensitive-message-formatter
```

## Usage

```
$stack->push(
    Middleware::log(
        $myLogger, 
        new sensitiveMessageFormatter(
            '{method} {uri} {req_body} - RESPONSE: {code} - {res_body}',
            ['myUsername', 'mySecretPassword']
        )
    ), 
    Logger::INFO
);
```

## Licence of this software (sensitive-message-formatter) [MIT]

(21.12.2024)

```
Copyright (c) D3 Data Development (Inh. Thomas Dartsch)

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
```