<?php

/**
 * Copyright (c) D3 Data Development (Inh. Thomas Dartsch)
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 *
 * https://www.d3data.de
 *
 * @copyright (C) D3 Data Development (Inh. Thomas Dartsch)
 * @author    D3 Data Development - Max Buhe, Daniel Seifert <info@shopmodule.com>
 * @link      https://www.oxidmodule.com
 */

declare(strict_types=1);

namespace D3\SensitiveMessageFormatter;

use GuzzleHttp\MessageFormatter;
use Psr\Http\Message\RequestInterface;
use Psr\Http\Message\ResponseInterface;
use Throwable;

class sensitiveMessageFormatter extends MessageFormatter
{
    /**
     * @param string|null $template
     * @param string[] $anonymizations
     * @param string|null $replaceChar
     */
    public function __construct(
        ?string $template = self::CLF,
        protected array $anonymizations = [],
        protected ?string $replaceChar = null
    ) {
        $this->createReplacements($this->anonymizations);

        parent::__construct($template);
    }

    /**
     * @param string[] $search
     * @return void
     */
    protected function createReplacements(array $search = []): void
    {
        $replacements = [];

        $this->replaceChar ??= '*';

        array_map(
            function ($search) use (&$replacements) {
                $replacements[$search] = str_repeat($this->replaceChar ?? '*', strlen($search));
                $replacements[urlencode($search)] = str_repeat($this->replaceChar ?? '*', strlen($search));
            },
            $search
        );

        $this->anonymizations = $replacements;
    }

    public function format(
        RequestInterface $request,
        ResponseInterface $response = null,
        Throwable $error = null
    ): string {
        $result = parent::format($request, $response, $error);

        if (count($this->anonymizations)) {
            $result = str_replace(
                array_keys($this->anonymizations),
                array_values($this->anonymizations),
                $result
            );
        }

        return $result;
    }
}
